@@ -226,9 +226,19 @@ static void feed_subscribed(MicrofeedSubscriber* subscriber, const char* publish
 
 static void error_occured(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const char* error_name, const char* error_message, void* user_data) {
 	MaukuWidget* mauku_widget;
+	const char* separator;
+	char* publisher_part;
+	GtkWidget* banner;
 	
 	mauku_widget = MAUKU_WIDGET(user_data);
-	
+	if ((separator = strchr(publisher, MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR))) {
+		publisher_part = g_strndup(publisher, separator - publisher);
+	} else {
+		publisher_part = g_strdup(publisher);
+	}
+	banner = hildon_banner_show_informationf(GTK_WIDGET(mauku_widget), "", "%s: %s", publisher_part, error_message);
+	hildon_banner_set_timeout(HILDON_BANNER(banner), 10000);
+	g_free(publisher_part);
 	printf("Failed: %s %s (%s): %s (%s)\n", publisher, uri, uid, error_name, error_message);
 }
 
@@ -264,7 +274,7 @@ static void item_added(MicrofeedSubscriber* subscriber, const char* publisher, c
 		if (!(sender_nick = microfeed_item_get_property(item, "user.nick"))) {
 			sender_nick = "<unknown>";
 		}
-		if ((s = strchr(publisher, ':'))) {
+		if ((s = strchr(publisher, MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR))) {
 			publisher_part = strndup(publisher, s - publisher);
 		} else {
 			publisher_part = strdup("<not specified>");
@@ -661,12 +671,10 @@ static void mauku_widget_init(MaukuWidget* mauku_widget) {
 	GdkColormap* colormap;
 	DBusError error;
 	DBusConnection* connection;
-	MicrofeedConfiguration* configuration;
 	const char** subscriptions;
 
 	mauku_widget->priv = G_TYPE_INSTANCE_GET_PRIVATE(mauku_widget, MAUKU_TYPE_WIDGET, MaukuWidgetPrivate);
 
-	configuration = microfeed_configuration_new();
 	microfeed_thread_init();
 
 	if ((colormap = gdk_screen_get_rgba_colormap(gdk_screen_get_default()))) {
@@ -707,8 +715,7 @@ static void mauku_widget_init(MaukuWidget* mauku_widget) {
 	dbus_error_init(&error);
 	connection = dbus_bus_get(DBUS_BUS_SESSION, &error);
 	dbus_connection_setup_with_g_main(connection, NULL);
-	configuration = microfeed_configuration_new();
-	mauku_widget->priv->subscriber = microfeed_subscriber_new(SUBSCRIBER_ID, "/com/innologies/mauku_widget", configuration, connection);
+	mauku_widget->priv->subscriber = microfeed_subscriber_new(SUBSCRIBER_ID, "/com/innologies/mauku_widget", connection);
 	microfeed_subscriber_handle_configured_subscriptions(mauku_widget->priv->subscriber, configured_subscribe, configured_unsubscribe, mauku_widget);
 }
 
